@@ -82,12 +82,21 @@ impl UserData {
         self.access_token.clone()
     }
 
-
     /// Get refresh token
     pub fn refresh_token(&self) -> Option<String> {
         self.refresh_token.clone()
     }
 
+    /// Set access token
+    pub fn set_access_token(&mut self, token: Option<String>) {
+        self.access_token = token;
+    }
+
+    /// Set refresh token
+    pub fn set_refresh_token(&mut self, token: Option<String>) {
+        self.refresh_token = token;
+    }
+
     /// Updates only the present values in the existing user data
     pub fn update(&mut self, new: UserData) {
         if let Some(n) = new.access_token {
@@ -278,12 +287,9 @@ impl EpicAPI {
 
         self.user_data.update(new);
 
-        match &self.user_data.error_message {
-            None => {}
-            Some(m) => {
-                error!("{}", m);
-                return Err(EpicAPIError::APIError(m.to_string()));
-            }
+        if let Some(m) = &self.user_data.error_message {
+            error!("{}", m);
+            return Err(EpicAPIError::APIError(m.to_string()));
         }
         Ok(true)
     }
@@ -328,19 +334,16 @@ impl EpicAPI {
     }
 
     pub async fn invalidate_sesion(&mut self) -> bool {
-        match &self.user_data.access_token {
-            None => {}
-            Some(access_token) => {
-                let url = format!("https://account-public-service-prod03.ol.epicgames.com/account/api/oauth/sessions/kill/{}", access_token);
-                let client = EpicAPI::build_client().build().unwrap();
-                match client.delete(Url::from_str(&url).unwrap()).send().await {
-                    Ok(_) => {
-                        info!("Session invalidated");
-                        return true;
-                    }
-                    Err(e) => {
-                        warn!("Unable to invalidate session: {}", e)
-                    }
+        if let Some(access_token) = &self.user_data.access_token {
+            let url = format!("https://account-public-service-prod03.ol.epicgames.com/account/api/oauth/sessions/kill/{}", access_token);
+            let client = EpicAPI::build_client().build().unwrap();
+            match client.delete(Url::from_str(&url).unwrap()).send().await {
+                Ok(_) => {
+                    info!("Session invalidated");
+                    return true;
+                }
+                Err(e) => {
+                    warn!("Unable to invalidate session: {}", e)
                 }
             }
         };
@@ -455,14 +458,14 @@ impl EpicAPI {
                 }
                 let url = format!("{}?{}", manifest.uri.to_string(), queries.join("&"));
                 let client = EpicAPI::build_client().build().unwrap();
-                match client.get(Url::from_str(&url).unwrap()).send().await {
+                return match client.get(Url::from_str(&url).unwrap()).send().await {
                     Ok(response) => {
                         if response.status() == reqwest::StatusCode::OK {
                             match response.bytes().await {
                                 Ok(data) => match DownloadManifest::parse(data.to_vec()) {
                                     None => {
                                         error!("Unable to parse the Download Manifest");
-                                        return Err(EpicAPIError::Unknown);
+                                        Err(EpicAPIError::Unknown)
                                     }
                                     Some(mut man) => {
                                         let mut url = manifest.uri.clone();
@@ -511,12 +514,12 @@ impl EpicAPI {
                                             "SourceURL".to_string(),
                                             url.to_string(),
                                         );
-                                        return Ok(man);
+                                        Ok(man)
                                     }
                                 },
                                 Err(e) => {
                                     error!("{:?}", e);
-                                    return Err(EpicAPIError::Unknown);
+                                    Err(EpicAPIError::Unknown)
                                 }
                             }
                         } else {
@@ -525,12 +528,12 @@ impl EpicAPI {
                                 response.status(),
                                 response.text().await.unwrap()
                             );
-                            return Err(EpicAPIError::Unknown);
+                            Err(EpicAPIError::Unknown)
                         }
                     }
                     Err(e) => {
                         error!("{:?}", e);
-                        return Err(EpicAPIError::Unknown);
+                        Err(EpicAPIError::Unknown)
                     }
                 }
             }
